@@ -1,3 +1,3 @@
 from .core import Nx3D
-from .examples import diffusion_example
+from .examples import diffusion, game_of_life
 from .simplified import demo, plot
